==> ejc-middlemeasurement-impl-3.0.0-20230130.073017-332-sources.jar: com/ejianc/business/middlemeasurement/bean/ConsultotherdetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 咨询及其他类合同过程结算单-计价明细
 *
 * @author generator
 *
 */
 @TableName("ejc_middlemeasurement_consultotherdetail")
public class ConsultotherdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="mid")
    private Long mid; // 主表id
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private String sort; // 序号
    @TableField(value="subitem_code")
    private String subitemCode; // 清单编号
    @TableField(value="subitem_name")
    private String subitemName; // 名称
    @TableField(value="spec")
    private String spec; // 规格及特征
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="quantity")
    private java.math.BigDecimal quantity; // 数量
    @TableField(value="unitprice")
    private java.math.BigDecimal unitprice; // 除税单价
    @TableField(value="tax_unitprice")
    private java.math.BigDecimal taxUnitprice; // 含税单价
    @TableField(value="amounts")
    private java.math.BigDecimal amounts; // 除税金额
    @TableField(value="tax_amounts")
    private java.math.BigDecimal taxAmounts; // 含税金额
    @TableField(value="cumulative_quantity")
    private java.math.BigDecimal cumulativeQuantity; // 数量
    @TableField(value="cumulative_amounts")
    private java.math.BigDecimal cumulativeAmounts; // 除税金额
    @TableField(value="cumulative_tax_amounts")
    private java.math.BigDecimal cumulativeTaxAmounts; // 含税金额
    @TableField(value="examine_quantity")
    private java.math.BigDecimal examineQuantity; // 数量
    @TableField(value="examine_unitprice")
    private java.math.BigDecimal examineUnitprice; // 除税单价
    @TableField(value="examine_tax_unitprice")
    private java.math.BigDecimal examineTaxUnitprice; // 含税单价
    @TableField(value="examine_amounts")
    private java.math.BigDecimal examineAmounts; // 除税金额
    @TableField(value="examine_tax_amounts")
    private java.math.BigDecimal examineTaxAmounts; // 含税金额
    @TableField(value="examine_cumulative_quantity")
    private java.math.BigDecimal examineCumulativeQuantity; // 数量
    @TableField(value="examine_cumulative_amounts")
    private java.math.BigDecimal examineCumulativeAmounts; // 除税金额
    @TableField(value="examine_cumulative_tax_amounts")
    private java.math.BigDecimal examineCumulativeTaxAmounts; // 含税金额
    @TableField(value="source")
    private String source; // 来源：1合同内 2合同外
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="tid")
    private String tid; // 表格行id
    @TableField(value="tpid")
    private String tpid; // 表格行父id
    @TableField(value="innercode")
    private String innercode; // 内码
    @TableField(value="contract_id")
    private Long contractId; // 合同id




    /**
     * 主表id
     */
    public Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(String sort) {
        this.sort = sort;
    }
    /**
     * 清单编号
     */
    public String getSubitemCode() {
        return subitemCode;
    }

    /**
     * 清单编号
     */
    public void setSubitemCode(String subitemCode) {
        this.subitemCode = subitemCode;
    }
    /**
     * 名称
     */
    public String getSubitemName() {
        return subitemName;
    }

    /**
     * 名称
     */
    public void setSubitemName(String subitemName) {
        this.subitemName = subitemName;
    }
    /**
     * 规格及特征
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格及特征
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getQuantity() {
        return quantity;
    }

    /**
     * 数量
     */
    public void setQuantity(java.math.BigDecimal quantity) {
        this.quantity = quantity;
    }
    /**
     * 除税单价
     */
    public java.math.BigDecimal getUnitprice() {
        return unitprice;
    }

    /**
     * 除税单价
     */
    public void setUnitprice(java.math.BigDecimal unitprice) {
        this.unitprice = unitprice;
    }
    /**
     * 含税单价
     */
    public java.math.BigDecimal getTaxUnitprice() {
        return taxUnitprice;
    }

    /**
     * 含税单价
     */
    public void setTaxUnitprice(java.math.BigDecimal taxUnitprice) {
        this.taxUnitprice = taxUnitprice;
    }
    /**
     * 除税金额
     */
    public java.math.BigDecimal getAmounts() {
        return amounts;
    }

    /**
     * 除税金额
     */
    public void setAmounts(java.math.BigDecimal amounts) {
        this.amounts = amounts;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getTaxAmounts() {
        return taxAmounts;
    }

    /**
     * 含税金额
     */
    public void setTaxAmounts(java.math.BigDecimal taxAmounts) {
        this.taxAmounts = taxAmounts;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getCumulativeQuantity() {
        return cumulativeQuantity;
    }

    /**
     * 数量
     */
    public void setCumulativeQuantity(java.math.BigDecimal cumulativeQuantity) {
        this.cumulativeQuantity = cumulativeQuantity;
    }
    /**
     * 除税金额
     */
    public java.math.BigDecimal getCumulativeAmounts() {
        return cumulativeAmounts;
    }

    /**
     * 除税金额
     */
    public void setCumulativeAmounts(java.math.BigDecimal cumulativeAmounts) {
        this.cumulativeAmounts = cumulativeAmounts;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getCumulativeTaxAmounts() {
        return cumulativeTaxAmounts;
    }

    /**
     * 含税金额
     */
    public void setCumulativeTaxAmounts(java.math.BigDecimal cumulativeTaxAmounts) {
        this.cumulativeTaxAmounts = cumulativeTaxAmounts;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getExamineQuantity() {
        return examineQuantity;
    }

    /**
     * 数量
     */
    public void setExamineQuantity(java.math.BigDecimal examineQuantity) {
        this.examineQuantity = examineQuantity;
    }
    /**
     * 除税单价
     */
    public java.math.BigDecimal getExamineUnitprice() {
        return examineUnitprice;
    }

    /**
     * 除税单价
     */
    public void setExamineUnitprice(java.math.BigDecimal examineUnitprice) {
        this.examineUnitprice = examineUnitprice;
    }
    /**
     * 含税单价
     */
    public java.math.BigDecimal getExamineTaxUnitprice() {
        return examineTaxUnitprice;
    }

    /**
     * 含税单价
     */
    public void setExamineTaxUnitprice(java.math.BigDecimal examineTaxUnitprice) {
        this.examineTaxUnitprice = examineTaxUnitprice;
    }
    /**
     * 除税金额
     */
    public java.math.BigDecimal getExamineAmounts() {
        return examineAmounts;
    }

    /**
     * 除税金额
     */
    public void setExamineAmounts(java.math.BigDecimal examineAmounts) {
        this.examineAmounts = examineAmounts;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getExamineTaxAmounts() {
        return examineTaxAmounts;
    }

    /**
     * 含税金额
     */
    public void setExamineTaxAmounts(java.math.BigDecimal examineTaxAmounts) {
        this.examineTaxAmounts = examineTaxAmounts;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getExamineCumulativeQuantity() {
        return examineCumulativeQuantity;
    }

    /**
     * 数量
     */
    public void setExamineCumulativeQuantity(java.math.BigDecimal examineCumulativeQuantity) {
        this.examineCumulativeQuantity = examineCumulativeQuantity;
    }
    /**
     * 除税金额
     */
    public java.math.BigDecimal getExamineCumulativeAmounts() {
        return examineCumulativeAmounts;
    }

    /**
     * 除税金额
     */
    public void setExamineCumulativeAmounts(java.math.BigDecimal examineCumulativeAmounts) {
        this.examineCumulativeAmounts = examineCumulativeAmounts;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getExamineCumulativeTaxAmounts() {
        return examineCumulativeTaxAmounts;
    }

    /**
     * 含税金额
     */
    public void setExamineCumulativeTaxAmounts(java.math.BigDecimal examineCumulativeTaxAmounts) {
        this.examineCumulativeTaxAmounts = examineCumulativeTaxAmounts;
    }
    /**
     * 来源：1合同内 2合同外
     */
    public String getSource() {
        return source;
    }

    /**
     * 来源：1合同内 2合同外
     */
    public void setSource(String source) {
        this.source = source;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 表格行id
     */
    public String getTid() {
        return tid;
    }

    /**
     * 表格行id
     */
    public void setTid(String tid) {
        this.tid = tid;
    }
    /**
     * 表格行父id
     */
    public String getTpid() {
        return tpid;
    }

    /**
     * 表格行父id
     */
    public void setTpid(String tpid) {
        this.tpid = tpid;
    }
    /**
     * 内码
     */
    public String getInnercode() {
        return innercode;
    }

    /**
     * 内码
     */
    public void setInnercode(String innercode) {
        this.innercode = innercode;
    }
    /**
     * 合同id
     */
    public Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

}

==> ejc-middlemeasurement-impl-3.0.0-20230830.034615-488-sources.jar: com/ejianc/business/middlemeasurement/bean/ConsultotherdetailEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 咨询及其他类合同过程结算单-计价明细
 *
 * @author generator
 *
 */
 @TableName("ejc_middlemeasurement_consultotherdetail")
public class ConsultotherdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="mid")
    private Long mid; // 主表id
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="sort")
    private String sort; // 序号
    @TableField(value="subitem_code")
    private String subitemCode; // 清单编号
    @TableField(value="subitem_name")
    private String subitemName; // 名称
    @TableField(value="spec")
    private String spec; // 规格及特征
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="quantity")
    private java.math.BigDecimal quantity; // 数量
    @TableField(value="unitprice")
    private java.math.BigDecimal unitprice; // 除税单价
    @TableField(value="tax_unitprice")
    private java.math.BigDecimal taxUnitprice; // 含税单价
    @TableField(value="amounts")
    private java.math.BigDecimal amounts; // 除税金额
    @TableField(value="tax_amounts")
    private java.math.BigDecimal taxAmounts; // 含税金额
    @TableField(value="cumulative_quantity")
    private java.math.BigDecimal cumulativeQuantity; // 数量
    @TableField(value="cumulative_amounts")
    private java.math.BigDecimal cumulativeAmounts; // 除税金额
    @TableField(value="cumulative_tax_amounts")
    private java.math.BigDecimal cumulativeTaxAmounts; // 含税金额
    @TableField(value="examine_quantity")
    private java.math.BigDecimal examineQuantity; // 数量
    @TableField(value="examine_unitprice")
    private java.math.BigDecimal examineUnitprice; // 除税单价
    @TableField(value="examine_tax_unitprice")
    private java.math.BigDecimal examineTaxUnitprice; // 含税单价
    @TableField(value="examine_amounts")
    private java.math.BigDecimal examineAmounts; // 除税金额
    @TableField(value="examine_tax_amounts")
    private java.math.BigDecimal examineTaxAmounts; // 含税金额
    @TableField(value="examine_cumulative_quantity")
    private java.math.BigDecimal examineCumulativeQuantity; // 数量
    @TableField(value="examine_cumulative_amounts")
    private java.math.BigDecimal examineCumulativeAmounts; // 除税金额
    @TableField(value="examine_cumulative_tax_amounts")
    private java.math.BigDecimal examineCumulativeTaxAmounts; // 含税金额
    @TableField(value="source")
    private String source; // 来源：1合同内 2合同外
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="tid")
    private String tid; // 表格行id
    @TableField(value="tpid")
    private String tpid; // 表格行父id
    @TableField(value="innercode")
    private String innercode; // 内码
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="settle_flag")
    private Boolean settleFlag;




    /**
     * 主表id
     */
    public Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(String sort) {
        this.sort = sort;
    }
    /**
     * 清单编号
     */
    public String getSubitemCode() {
        return subitemCode;
    }

    /**
     * 清单编号
     */
    public void setSubitemCode(String subitemCode) {
        this.subitemCode = subitemCode;
    }
    /**
     * 名称
     */
    public String getSubitemName() {
        return subitemName;
    }

    /**
     * 名称
     */
    public void setSubitemName(String subitemName) {
        this.subitemName = subitemName;
    }
    /**
     * 规格及特征
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格及特征
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getQuantity() {
        return quantity;
    }

    /**
     * 数量
     */
    public void setQuantity(java.math.BigDecimal quantity) {
        this.quantity = quantity;
    }
    /**
     * 除税单价
     */
    public java.math.BigDecimal getUnitprice() {
        return unitprice;
    }

    /**
     * 除税单价
     */
    public void setUnitprice(java.math.BigDecimal unitprice) {
        this.unitprice = unitprice;
    }
    /**
     * 含税单价
     */
    public java.math.BigDecimal getTaxUnitprice() {
        return taxUnitprice;
    }

    /**
     * 含税单价
     */
    public void setTaxUnitprice(java.math.BigDecimal taxUnitprice) {
        this.taxUnitprice = taxUnitprice;
    }
    /**
     * 除税金额
     */
    public java.math.BigDecimal getAmounts() {
        return amounts;
    }

    /**
     * 除税金额
     */
    public void setAmounts(java.math.BigDecimal amounts) {
        this.amounts = amounts;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getTaxAmounts() {
        return taxAmounts;
    }

    /**
     * 含税金额
     */
    public void setTaxAmounts(java.math.BigDecimal taxAmounts) {
        this.taxAmounts = taxAmounts;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getCumulativeQuantity() {
        return cumulativeQuantity;
    }

    /**
     * 数量
     */
    public void setCumulativeQuantity(java.math.BigDecimal cumulativeQuantity) {
        this.cumulativeQuantity = cumulativeQuantity;
    }
    /**
     * 除税金额
     */
    public java.math.BigDecimal getCumulativeAmounts() {
        return cumulativeAmounts;
    }

    /**
     * 除税金额
     */
    public void setCumulativeAmounts(java.math.BigDecimal cumulativeAmounts) {
        this.cumulativeAmounts = cumulativeAmounts;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getCumulativeTaxAmounts() {
        return cumulativeTaxAmounts;
    }

    /**
     * 含税金额
     */
    public void setCumulativeTaxAmounts(java.math.BigDecimal cumulativeTaxAmounts) {
        this.cumulativeTaxAmounts = cumulativeTaxAmounts;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getExamineQuantity() {
        return examineQuantity;
    }

    /**
     * 数量
     */
    public void setExamineQuantity(java.math.BigDecimal examineQuantity) {
        this.examineQuantity = examineQuantity;
    }
    /**
     * 除税单价
     */
    public java.math.BigDecimal getExamineUnitprice() {
        return examineUnitprice;
    }

    /**
     * 除税单价
     */
    public void setExamineUnitprice(java.math.BigDecimal examineUnitprice) {
        this.examineUnitprice = examineUnitprice;
    }
    /**
     * 含税单价
     */
    public java.math.BigDecimal getExamineTaxUnitprice() {
        return examineTaxUnitprice;
    }

    /**
     * 含税单价
     */
    public void setExamineTaxUnitprice(java.math.BigDecimal examineTaxUnitprice) {
        this.examineTaxUnitprice = examineTaxUnitprice;
    }
    /**
     * 除税金额
     */
    public java.math.BigDecimal getExamineAmounts() {
        return examineAmounts;
    }

    /**
     * 除税金额
     */
    public void setExamineAmounts(java.math.BigDecimal examineAmounts) {
        this.examineAmounts = examineAmounts;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getExamineTaxAmounts() {
        return examineTaxAmounts;
    }

    /**
     * 含税金额
     */
    public void setExamineTaxAmounts(java.math.BigDecimal examineTaxAmounts) {
        this.examineTaxAmounts = examineTaxAmounts;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getExamineCumulativeQuantity() {
        return examineCumulativeQuantity;
    }

    /**
     * 数量
     */
    public void setExamineCumulativeQuantity(java.math.BigDecimal examineCumulativeQuantity) {
        this.examineCumulativeQuantity = examineCumulativeQuantity;
    }
    /**
     * 除税金额
     */
    public java.math.BigDecimal getExamineCumulativeAmounts() {
        return examineCumulativeAmounts;
    }

    /**
     * 除税金额
     */
    public void setExamineCumulativeAmounts(java.math.BigDecimal examineCumulativeAmounts) {
        this.examineCumulativeAmounts = examineCumulativeAmounts;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getExamineCumulativeTaxAmounts() {
        return examineCumulativeTaxAmounts;
    }

    /**
     * 含税金额
     */
    public void setExamineCumulativeTaxAmounts(java.math.BigDecimal examineCumulativeTaxAmounts) {
        this.examineCumulativeTaxAmounts = examineCumulativeTaxAmounts;
    }
    /**
     * 来源：1合同内 2合同外
     */
    public String getSource() {
        return source;
    }

    /**
     * 来源：1合同内 2合同外
     */
    public void setSource(String source) {
        this.source = source;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 表格行id
     */
    public String getTid() {
        return tid;
    }

    /**
     * 表格行id
     */
    public void setTid(String tid) {
        this.tid = tid;
    }
    /**
     * 表格行父id
     */
    public String getTpid() {
        return tpid;
    }

    /**
     * 表格行父id
     */
    public void setTpid(String tpid) {
        this.tpid = tpid;
    }
    /**
     * 内码
     */
    public String getInnercode() {
        return innercode;
    }

    /**
     * 内码
     */
    public void setInnercode(String innercode) {
        this.innercode = innercode;
    }
    /**
     * 合同id
     */
    public Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }


    public Boolean getSettleFlag() {
        return settleFlag;
    }

    public void setSettleFlag(Boolean settleFlag) {
        this.settleFlag = settleFlag;
    }
}
